@@ -530,7 +530,7 @@ brasero_data_session_stop_io (BraseroDataSession *self)
 
 	if (priv->load_dir) {
 		brasero_io_cancel_by_base (priv->load_dir);
-		g_free (priv->load_dir);
+		brasero_io_job_base_free (priv->load_dir);
 		priv->load_dir = NULL;
 	}
 }
