@@ -31,23 +31,21 @@
 
 #include <glib.h>
 #include <glib/gi18n-lib.h>
+#include <glib/gstdio.h>
 #include <glib-object.h>
 
-#include <gtk/gtkwidget.h>
-#include <gtk/gtkeventbox.h>
-#include <gtk/gtkimage.h>
-#include <gtk/gtkimage.h>
-#include <gtk/gtktable.h>
-#include <gtk/gtkcontainer.h>
-#include <gtk/gtkmisc.h>
+#include <gtk/gtk.h>
+
+#include "brasero-app.h"
+#include "brasero-utils.h"
+#include "brasero-session.h"
 
 #include "brasero-project-type-chooser.h"
-#include "brasero-utils.h"
-
 
 G_DEFINE_TYPE (BraseroProjectTypeChooser, brasero_project_type_chooser, GTK_TYPE_EVENT_BOX);
 
 typedef enum {
+	LAST_SAVED_CLICKED_SIGNAL,
 	RECENT_CLICKED_SIGNAL,
 	CHOSEN_SIGNAL,
 	LAST_SIGNAL
@@ -71,27 +69,27 @@ struct _ItemDescription {
 typedef struct _ItemDescription ItemDescription;
 
 static ItemDescription items [] = {
-       {N_("<big>Audi_o project</big>"),
+       {N_("Audi_o project"),
 	N_("Create a traditional audio CD"),
 	N_("Create a traditional audio CD that will be playable on computers and stereos"),
 	"media-optical-audio-new",
 	BRASERO_PROJECT_TYPE_AUDIO},
-       {N_("<big>D_ata project</big>"),
+       {N_("D_ata project"),
 	N_("Create a data CD/DVD"),
 	N_("Create a CD/DVD containing any type of data that can only be read on a computer"),
 	"media-optical-data-new",
 	BRASERO_PROJECT_TYPE_DATA},
-       {N_("<big>_Video project</big>"),
+       {N_("_Video project"),
 	N_("Create a video DVD or a SVCD"),
 	N_("Create a video DVD or a SVCD that are readable on TV readers"),
 	"media-optical-video-new",
 	BRASERO_PROJECT_TYPE_VIDEO},
-       {N_("<big>Disc _copy</big>"),
+       {N_("Disc _copy"),
 	N_("Create 1:1 copy of a CD/DVD"),
-	N_("Create a 1:1 copy of an audio CD or a data CD/DVD on your hardisk or on another CD/DVD"),
+	N_("Create a 1:1 copy of an audio CD or a data CD/DVD on your hard disk or on another CD/DVD"),
 	"media-optical-copy",
 	BRASERO_PROJECT_TYPE_COPY},
-       {N_("<big>Burn _image</big>"),
+       {N_("Burn _image"),
 	N_("Burn an existing CD/DVD image to disc"),
 	N_("Burn an existing CD/DVD image to disc"),
 	"iso-image-burn",
@@ -131,6 +129,7 @@ brasero_project_type_chooser_new_item (BraseroProjectTypeChooser *chooser,
 	GtkWidget *image;
 	GtkWidget *label;
 	GtkWidget *eventbox;
+	gchar *description_str;
 
 	eventbox = gtk_button_new ();
 	g_signal_connect (eventbox,
@@ -149,28 +148,33 @@ brasero_project_type_chooser_new_item (BraseroProjectTypeChooser *chooser,
 			   DESCRIPTION_KEY,
 			   description);
 
-
 	vbox = gtk_vbox_new (FALSE, 0);
 	gtk_container_set_border_width (GTK_CONTAINER (vbox), 4);
 	gtk_container_add (GTK_CONTAINER (eventbox), vbox);
 
-	hbox = gtk_hbox_new (FALSE, 6);
+	hbox = gtk_hbox_new (FALSE, 4);
 	gtk_box_pack_start (GTK_BOX (vbox), hbox, TRUE, FALSE, 0);
 
 	image = gtk_image_new_from_icon_name (description->image, GTK_ICON_SIZE_DIALOG);
 	gtk_misc_set_alignment (GTK_MISC (image), 1.0, 0.5);
-	gtk_box_pack_start (GTK_BOX (hbox), image, TRUE, TRUE, 0);
+	gtk_box_pack_start (GTK_BOX (hbox), image, FALSE, FALSE, 0);
+
+	vbox = gtk_vbox_new (TRUE, 4);
+	gtk_box_pack_start (GTK_BOX (hbox), vbox, FALSE, TRUE, 0);
 
 	label = gtk_label_new (NULL);
 	gtk_label_set_mnemonic_widget (GTK_LABEL (label), eventbox);
-	gtk_label_set_markup_with_mnemonic (GTK_LABEL (label), _(description->text));
+	description_str = g_strdup_printf ("<big>%s</big>", _(description->text));
+	gtk_label_set_markup_with_mnemonic (GTK_LABEL (label), description_str);
+	g_free (description_str);
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-	gtk_box_pack_start (GTK_BOX (hbox), label, TRUE, TRUE, 0);
+	gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, TRUE, 0);
 	g_object_set_data (G_OBJECT (eventbox), LABEL_KEY, label);
 
 	label = gtk_label_new (NULL);
+	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 	gtk_label_set_markup (GTK_LABEL (label), _(description->description));
-	gtk_box_pack_start (GTK_BOX (vbox), label, TRUE, TRUE, 0);
+	gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, TRUE, 0);
 
 	return eventbox;
 }
@@ -181,13 +185,32 @@ brasero_project_type_chooser_recent_clicked_cb (GtkButton *button,
 {
 	const gchar *uri;
 
-	uri = gtk_link_button_get_uri (GTK_LINK_BUTTON (button));
+	uri = g_object_get_data (G_OBJECT (button), "BraseroButtonURI");
 	g_signal_emit (self,
 		       brasero_project_type_chooser_signals [RECENT_CLICKED_SIGNAL],
 		       0,
 		       uri);
 }
 
+static void
+brasero_project_type_chooser_last_unsaved_clicked_cb (GtkButton *button,
+						      BraseroProjectTypeChooser *self)
+{
+	const gchar *uri;
+	gchar *path;
+
+	uri = g_object_get_data (G_OBJECT (button), "BraseroButtonURI");
+	path = g_filename_from_uri (uri, NULL, NULL);
+
+	g_signal_emit (self,
+		       brasero_project_type_chooser_signals [LAST_SAVED_CLICKED_SIGNAL],
+		       0,
+		       path);
+
+	g_remove (path);
+	g_free (path);
+}
+
 static gint
 brasero_project_type_chooser_sort_recent (gconstpointer a, gconstpointer b)
 {
@@ -210,7 +233,10 @@ static void
 brasero_project_type_chooser_build_recent (BraseroProjectTypeChooser *self,
 					   GtkRecentManager *recent)
 {
+	GtkSizeGroup *image_group;
+	GtkSizeGroup *group;
 	GList *list = NULL;
+	gchar *filename;
 	GList *recents;
 	GList *iter;
 
@@ -244,31 +270,67 @@ brasero_project_type_chooser_build_recent (BraseroProjectTypeChooser *self,
 			list = g_list_delete_link (list, g_list_last (list));
 	}
 
+	group = gtk_size_group_new (GTK_SIZE_GROUP_BOTH);
+	image_group = gtk_size_group_new (GTK_SIZE_GROUP_BOTH);
+
+	/* If a project was left unfinished last time then add another entry */
+	filename = g_build_filename (g_get_user_config_dir (),
+				     "brasero",
+				     BRASERO_SESSION_TMP_PROJECT_PATH,
+				     NULL);
+	if (g_file_test (filename, G_FILE_TEST_EXISTS)) {
+		gchar *uri;
+		GtkWidget *link;
+		GtkWidget *image;
+
+		uri = g_filename_to_uri (filename, NULL, NULL);
+
+		image = gtk_image_new_from_icon_name ("brasero", GTK_ICON_SIZE_BUTTON);
+		gtk_size_group_add_widget (image_group, image);
+
+		link = gtk_button_new_with_label (_("Last _Unsaved Project"));
+		g_object_set_data_full (G_OBJECT (link),
+					"BraseroButtonURI", uri,
+					g_free);
+
+		gtk_button_set_relief (GTK_BUTTON (link), GTK_RELIEF_NONE);
+		gtk_button_set_alignment (GTK_BUTTON (link), 0.0, 0.5);
+		gtk_button_set_focus_on_click (GTK_BUTTON (link), FALSE);
+		gtk_button_set_image (GTK_BUTTON (link), image);
+		gtk_button_set_use_underline (GTK_BUTTON (link), TRUE);
+		g_signal_connect (link,
+				  "clicked",
+				  G_CALLBACK (brasero_project_type_chooser_last_unsaved_clicked_cb),
+				  self);
+
+		gtk_widget_show (link);
+		gtk_widget_set_tooltip_text (link, _("Load the last project that was not burnt and not saved"));
+		gtk_box_pack_start (GTK_BOX (self->priv->recent_box), link, FALSE, TRUE, 0);
+
+		gtk_size_group_add_widget (group, link);
+	}
+	g_free (filename);
+
 	for (iter = list; iter; iter = iter->next) {
 		GtkRecentInfo *info;
+		GList *child_iter;
 		const gchar *name;
 		GdkPixbuf *pixbuf;
 		GtkWidget *image;
 		const gchar *uri;
-		GtkWidget *hbox;
+		GtkWidget *child;
 		GtkWidget *link;
+		GList *children;
 		gchar *tooltip;
 
 		info = iter->data;
 
-		hbox = gtk_hbox_new (FALSE, 6);
-		gtk_widget_show (hbox);
-		gtk_box_pack_start (GTK_BOX (self->priv->recent_box),
-				    hbox,
-				    FALSE,
-				    FALSE,
-				    0);
-
 		tooltip = gtk_recent_info_get_uri_display (info);
 
 		pixbuf = gtk_recent_info_get_icon (info, GTK_ICON_SIZE_BUTTON);
 		image = gtk_image_new_from_pixbuf (pixbuf);
 		g_object_unref (pixbuf);
+		gtk_size_group_add_widget (image_group, image);
 
 		gtk_widget_show (image);
 		gtk_widget_set_tooltip_text (image, tooltip);
@@ -276,25 +338,83 @@ brasero_project_type_chooser_build_recent (BraseroProjectTypeChooser *self,
 		name = gtk_recent_info_get_display_name (info);
 		uri = gtk_recent_info_get_uri (info);
 
-		link = gtk_link_button_new_with_label (uri, name);
-		gtk_button_set_focus_on_click (GTK_BUTTON (link), FALSE);
+		/* Don't use mnemonics with filenames */
+		link = gtk_button_new_with_label (name);
+		g_object_set_data_full (G_OBJECT (link),
+					"BraseroButtonURI", g_strdup (uri),
+					g_free);
+
+		gtk_button_set_relief (GTK_BUTTON (link), GTK_RELIEF_NONE);
 		gtk_button_set_image (GTK_BUTTON (link), image);
+		gtk_button_set_alignment (GTK_BUTTON (link), 0.0, 0.5);
+		gtk_button_set_focus_on_click (GTK_BUTTON (link), FALSE);
 		g_signal_connect (link,
 				  "clicked",
 				  G_CALLBACK (brasero_project_type_chooser_recent_clicked_cb),
 				  self);
-
 		gtk_widget_show (link);
+
 		gtk_widget_set_tooltip_text (link, tooltip);
-		gtk_box_pack_start (GTK_BOX (hbox), link, FALSE, FALSE, 0);
+		gtk_box_pack_start (GTK_BOX (self->priv->recent_box), link, FALSE, TRUE, 0);
 
 		g_free (tooltip);
+
+		gtk_size_group_add_widget (group, link);
+
+		/* That's a tedious hack to avoid mnemonics which are hardcoded
+		 * when you add an image to a button. BUG? */
+		if (!GTK_IS_BIN (link))
+			continue;
+
+		child = gtk_bin_get_child (GTK_BIN (link));
+		if (!GTK_IS_ALIGNMENT (child))
+			continue;
+
+		gtk_alignment_set (GTK_ALIGNMENT (child),
+				   0.0,
+				   0.5,
+				   1.0,
+				   1.0);
+
+		child = gtk_bin_get_child (GTK_BIN (child));
+		if (!GTK_IS_BOX (child))
+			continue;
+
+		children = gtk_container_get_children (GTK_CONTAINER (child));
+		for (child_iter = children; child_iter; child_iter = child_iter->next) {
+			GtkWidget *widget;
+
+			widget = child_iter->data;
+			if (GTK_IS_LABEL (widget)) {
+				gtk_label_set_use_underline (GTK_LABEL (widget), FALSE);
+				gtk_misc_set_alignment (GTK_MISC (widget), 0.0, 0.5);
+
+				/* Make sure that the name is not too long */
+				gtk_box_set_child_packing (GTK_BOX (child),
+							   widget,
+							   TRUE,
+							   TRUE,
+							   0,
+							   GTK_PACK_START);
+				gtk_label_set_ellipsize (GTK_LABEL (widget),
+							 PANGO_ELLIPSIZE_END);
+				break;
+			}
+		}
+		g_list_free (children);
 	}
+	g_object_unref (image_group);
+	g_object_unref (group);
 
 	if (!g_list_length (list)) {
 		GtkWidget *label;
+		gchar *string;
+
+		string = g_strdup_printf ("<i>%s</i>", _("No recently used project"));
+		label = gtk_label_new (string);
+		gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
+		g_free (string);
 
-		label = gtk_label_new (_("No recently used project"));
 		gtk_widget_show (label);
 		gtk_box_pack_start (GTK_BOX (self->priv->recent_box), label, FALSE, FALSE, 0);
 	}
@@ -322,11 +442,13 @@ brasero_project_type_chooser_init (BraseroProjectTypeChooser *obj)
 	GtkWidget *project_box;
 	GtkWidget *recent_box;
 	GError *error = NULL;
+	GtkWidget *separator;
 	GtkWidget *widget;
 	GtkWidget *table;
 	GtkWidget *label;
 	GtkWidget *vbox;
-	int nb_rows = 2;
+	int nb_rows = 1;
+	gchar *string;
 	int nb_items;
 	int rows;
 	int i;
@@ -340,26 +462,24 @@ brasero_project_type_chooser_init (BraseroProjectTypeChooser *obj)
 		error = NULL;
 	}
 
-	vbox = gtk_vbox_new (FALSE, 0);
+	vbox = gtk_hbox_new (FALSE, 0);
+	gtk_container_set_border_width (GTK_CONTAINER (vbox), 12);
 	gtk_widget_show (vbox);
 	gtk_container_add (GTK_CONTAINER (obj), vbox);
 
+	/* Project box */
 	project_box = gtk_vbox_new (FALSE, 6);
-	gtk_container_set_border_width (GTK_CONTAINER (project_box), 12);
 	gtk_widget_show (project_box);
-	gtk_box_pack_start (GTK_BOX (vbox), project_box, FALSE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (vbox), project_box, FALSE, TRUE, 0);
+
+	string = g_strdup_printf ("<span size='x-large'><b>%s</b></span>", _("Create a new project:"));
+	label = gtk_label_new (string);
+	g_free (string);
 
-	label = gtk_label_new (_("<span size='x-large'><b>Create a new project:</b></span>"));
 	gtk_widget_show (label);
 	gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
-	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-	gtk_box_pack_start (GTK_BOX (project_box), label, FALSE, FALSE, 0);
-
-	label = gtk_label_new (_("<span foreground='grey50'><b><i>Choose from the following options</i></b></span>"));
-	gtk_widget_show (label);
-	gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
-	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-	gtk_box_pack_start (GTK_BOX (project_box), label, FALSE, FALSE, 0);
+	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.0);
+	gtk_box_pack_start (GTK_BOX (project_box), label, FALSE, TRUE, 0);
 
 	/* get the number of rows */
 	nb_items = sizeof (items) / sizeof (ItemDescription);
@@ -368,11 +488,11 @@ brasero_project_type_chooser_init (BraseroProjectTypeChooser *obj)
 		rows ++;
 
 	table = gtk_table_new (rows, nb_rows, TRUE);
-	gtk_container_set_border_width (GTK_CONTAINER (table), 12);
-	gtk_box_pack_start (GTK_BOX (project_box), table, FALSE, FALSE, 6);
+	gtk_container_set_border_width (GTK_CONTAINER (table), 6);
+	gtk_box_pack_start (GTK_BOX (project_box), table, FALSE, TRUE, 0);
 
-	gtk_table_set_col_spacings (GTK_TABLE (table), 12);
-	gtk_table_set_row_spacings (GTK_TABLE (table), 12);
+	gtk_table_set_col_spacings (GTK_TABLE (table), 4);
+	gtk_table_set_row_spacings (GTK_TABLE (table), 4);
 
 	for (i = 0; i < nb_items; i ++) {
 		widget = brasero_project_type_chooser_new_item (obj, items + i);
@@ -389,22 +509,28 @@ brasero_project_type_chooser_init (BraseroProjectTypeChooser *obj)
 	}
 	gtk_widget_show_all (table);
 
+	separator = gtk_vseparator_new ();
+	gtk_widget_show (separator);
+	gtk_box_pack_start (GTK_BOX (vbox), separator, FALSE, TRUE, 8);
+
 	/* The recent files part */
 	recent_box = gtk_vbox_new (FALSE, 0);
-	gtk_container_set_border_width (GTK_CONTAINER (recent_box), 12);
 	gtk_widget_show (recent_box);
-	gtk_box_pack_start (GTK_BOX (vbox), recent_box, FALSE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (vbox), recent_box, TRUE, TRUE, 0);
+
+	string = g_strdup_printf ("<span size='x-large'><b>%s</b></span>", _("Recent projects:"));
+	label = gtk_label_new (string);
+	g_free (string);
 
-	label = gtk_label_new (_("<span size='x-large'><b>Choose a recently opened project:</b></span>"));
 	gtk_widget_show (label);
 	gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
-	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-	gtk_box_pack_start (GTK_BOX (recent_box), label, FALSE, FALSE, 12);
+	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.0);
+	gtk_box_pack_start (GTK_BOX (recent_box), label, FALSE, TRUE, 0);
 
-	vbox = gtk_vbox_new (FALSE, 6);
-	gtk_container_set_border_width (GTK_CONTAINER (vbox), 12);
+	vbox = gtk_vbox_new (TRUE, 0);
 	gtk_widget_show (vbox);
-	gtk_box_pack_start (GTK_BOX (recent_box), vbox, FALSE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (recent_box), vbox, FALSE, TRUE, 0);
+	gtk_container_set_border_width (GTK_CONTAINER (vbox), 12);
 	obj->priv->recent_box = vbox;
 
 	recent = gtk_recent_manager_get_default ();
@@ -496,6 +622,15 @@ brasero_project_type_chooser_class_init (BraseroProjectTypeChooserClass *klass)
 			  G_TYPE_NONE,
 			  1,
 			  G_TYPE_STRING);
+	brasero_project_type_chooser_signals[LAST_SAVED_CLICKED_SIGNAL] =
+	    g_signal_new ("last_saved", G_OBJECT_CLASS_TYPE (object_class),
+			  G_SIGNAL_ACTION | G_SIGNAL_RUN_FIRST,
+			  G_STRUCT_OFFSET (BraseroProjectTypeChooserClass, last_saved_clicked),
+			  NULL, NULL,
+			  g_cclosure_marshal_VOID__STRING,
+			  G_TYPE_NONE,
+			  1,
+			  G_TYPE_STRING);
 }
 
 GtkWidget *
